@@ -131,6 +131,10 @@ def grid_form(request, grid, read_only=False):
     if grid and not grid.group_by:
         if grid_table and len(grid_table.reports) > 0:
             context['reports'] = grid_table.reports
+        mailings = grid_table.mailing_builder(grid_table) if grid_table and grid_table.mailing_builder else []
+        if grid_table and len(mailings) > 0:
+            context['mailings'] = mailings
+            context['mailing_url'] = grid_table.mailing_url
 
     fields = grid_table.fields if grid_table else None
     context['fields'] = fields
